@@ -1,6 +1,7 @@
 #-*- encoding: utf-8 -*-
-VERSION='0.3.5'
-import sys
+VERSION='0.3.6'
+MAX_RETRIES=3
+import sys, time
 try:
     from urllib.request import urlopen, Request
     from urllib.parse import quote_plus
@@ -20,7 +21,6 @@ class JSONScraper(object):
     def __init__(self, logger):
         object.__init__(self)
         self.logger = logger
-        
     '''
         Download Data from an url and returns it as a String
         @param url Url to download from (e.g. http://www.google.com)
@@ -29,17 +29,20 @@ class JSONScraper(object):
     '''
     def downloadWebData(self, url, headers=None):
         data = ""
-        try:
-            req = Request(url)
-            req.add_header(Keys.USER_AGENT, Keys.USER_AGENT_STRING)
-            response = urlopen(req)
-            
-            if sys.version_info < (3, 0):
-                data = response.read()
-            else:
-                data = response.readall().decode('utf-8')
-            response.close()
-        except:
+        req = Request(url)
+        req.add_header(Keys.USER_AGENT, Keys.USER_AGENT_STRING)
+        for _ in range(MAX_RETRIES):
+            try:
+                response = urlopen(req)
+                if sys.version_info < (3, 0):
+                    data = response.read()
+                else:
+                    data = response.readall().decode('utf-8')
+                response.close()
+                break
+            except Exception as err:
+                pass
+        else:
             raise TwitchException(TwitchException.HTTP_ERROR)
         return data
 
@@ -50,10 +53,7 @@ class JSONScraper(object):
         @returns JSON Object with data from URL
     '''
     def getJson(self, url, headers=None):
-        try:
-            jsonString = self.downloadWebData(url, headers)
-        except:
-            raise TwitchException(TwitchException.HTTP_ERROR)
+        jsonString = self.downloadWebData(url, headers)
         try:
             jsonDict = json.loads(jsonString)
             self.logger.debug(json.dumps(jsonDict, indent=4, sort_keys=True))
